@@ -56,8 +56,8 @@ PlotLog2ByteEcdf <- function(x,
        ylab=ylab,
        ...
        )
-  if (require(gdata)) {
-    labs <- humanReadable(power.of.two.breaks)
+  if (requireNamespace("gdata", quietly=TRUE)) {
+    labs <- gdata::humanReadable(power.of.two.breaks)
   } else {
     labs <- power.of.two.breaks
   }
